# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/iomeval',
                'doc_host': 'https://franckalbinet.github.io',
                'git_url': 'https://github.com/franckalbinet/iomeval',
                'lib_path': 'iomeval'},
  'syms': { 'iomeval.core': { 'iomeval.core.load_prompt': ('core.html#load_prompt', 'iomeval/core.py'),
                              'iomeval.core.n_tokens': ('core.html#n_tokens', 'iomeval/core.py')},
            'iomeval.downloaders': { 'iomeval.downloaders.download_eval': ('downloaders.html#download_eval', 'iomeval/downloaders.py'),
                                     'iomeval.downloaders.download_evals': ('downloaders.html#download_evals', 'iomeval/downloaders.py')},
            'iomeval.extract': { 'iomeval.extract.CoreSectionsOutput': ('extract.html#coresectionsoutput', 'iomeval/extract.py'),
                                 'iomeval.extract.extract_sections': ('extract.html#extract_sections', 'iomeval/extract.py'),
                                 'iomeval.extract.get_text': ('extract.html#get_text', 'iomeval/extract.py'),
                                 'iomeval.extract.identify_core_sections': ('extract.html#identify_core_sections', 'iomeval/extract.py'),
                                 'iomeval.extract.rm_nested': ('extract.html#rm_nested', 'iomeval/extract.py')},
            'iomeval.mapper': { 'iomeval.mapper.ThemeScore': ('mapper.html#themescore', 'iomeval/mapper.py'),
                                'iomeval.mapper.ThemeScores': ('mapper.html#themescores', 'iomeval/mapper.py'),
                                'iomeval.mapper.get_top_ids': ('mapper.html#get_top_ids', 'iomeval/mapper.py'),
                                'iomeval.mapper.load_prompts': ('mapper.html#load_prompts', 'iomeval/mapper.py'),
                                'iomeval.mapper.map_all': ('mapper.html#map_all', 'iomeval/mapper.py'),
                                'iomeval.mapper.map_themes': ('mapper.html#map_themes', 'iomeval/mapper.py'),
                                'iomeval.mapper.mk_system_blocks': ('mapper.html#mk_system_blocks', 'iomeval/mapper.py'),
                                'iomeval.mapper.parse_json_response': ('mapper.html#parse_json_response', 'iomeval/mapper.py'),
                                'iomeval.mapper.sort_by_centrality': ('mapper.html#sort_by_centrality', 'iomeval/mapper.py')},
            'iomeval.pipeline': { 'iomeval.pipeline.Report': ('pipeline.html#report', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.__init__': ('pipeline.html#report.__init__', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report._ensure_sys_blocks': ( 'pipeline.html#report._ensure_sys_blocks',
                                                                                  'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report._repr_markdown_': ( 'pipeline.html#report._repr_markdown_',
                                                                               'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.download': ('pipeline.html#report.download', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.extract': ('pipeline.html#report.extract', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.from_title': ('pipeline.html#report.from_title', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.from_url': ('pipeline.html#report.from_url', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.map_all': ('pipeline.html#report.map_all', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.map_ccps': ('pipeline.html#report.map_ccps', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.map_enablers': ('pipeline.html#report.map_enablers', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.map_gcm': ('pipeline.html#report.map_gcm', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.map_outputs': ('pipeline.html#report.map_outputs', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.ocr': ('pipeline.html#report.ocr', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.Report.save': ('pipeline.html#report.save', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline._map_single': ('pipeline.html#_map_single', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.load_report': ('pipeline.html#load_report', 'iomeval/pipeline.py'),
                                  'iomeval.pipeline.run_pipeline': ('pipeline.html#run_pipeline', 'iomeval/pipeline.py')},
            'iomeval.readers': { 'iomeval.readers.EvalReader': ('readers.html#evalreader', 'iomeval/readers.py'),
                                 'iomeval.readers.EvalReader.__call__': ('readers.html#evalreader.__call__', 'iomeval/readers.py'),
                                 'iomeval.readers.EvalReader.__init__': ('readers.html#evalreader.__init__', 'iomeval/readers.py'),
                                 'iomeval.readers.EvalReader.read': ('readers.html#evalreader.read', 'iomeval/readers.py'),
                                 'iomeval.readers.EvalReader.tfm': ('readers.html#evalreader.tfm', 'iomeval/readers.py'),
                                 'iomeval.readers.EvalReader.to_json': ('readers.html#evalreader.to_json', 'iomeval/readers.py'),
                                 'iomeval.readers.Evaluation': ('readers.html#evaluation', 'iomeval/readers.py'),
                                 'iomeval.readers.Evaluation._repr_markdown_': ( 'readers.html#evaluation._repr_markdown_',
                                                                                 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader': ('readers.html#iomreporeader', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader.__init__': ('readers.html#iomreporeader.__init__', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader._mk_docs': ('readers.html#iomreporeader._mk_docs', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader._mk_id': ('readers.html#iomreporeader._mk_id', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader._proc_dates': ( 'readers.html#iomreporeader._proc_dates',
                                                                                'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader._proc_lists': ( 'readers.html#iomreporeader._proc_lists',
                                                                                'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader._to_dict': ('readers.html#iomreporeader._to_dict', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader._to_eval': ('readers.html#iomreporeader._to_eval', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader.read': ('readers.html#iomreporeader.read', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader.tfm': ('readers.html#iomreporeader.tfm', 'iomeval/readers.py'),
                                 'iomeval.readers.IOMRepoReader.to_json': ('readers.html#iomreporeader.to_json', 'iomeval/readers.py'),
                                 'iomeval.readers.find_eval': ('readers.html#find_eval', 'iomeval/readers.py'),
                                 'iomeval.readers.in_docs': ('readers.html#in_docs', 'iomeval/readers.py'),
                                 'iomeval.readers.iom_input_cfg': ('readers.html#iom_input_cfg', 'iomeval/readers.py'),
                                 'iomeval.readers.load_evals': ('readers.html#load_evals', 'iomeval/readers.py')},
            'iomeval.themes': { 'iomeval.themes._load': ('themes.html#_load', 'iomeval/themes.py'),
                                'iomeval.themes.fmt_enablers_ccp': ('themes.html#fmt_enablers_ccp', 'iomeval/themes.py'),
                                'iomeval.themes.fmt_srf_out': ('themes.html#fmt_srf_out', 'iomeval/themes.py'),
                                'iomeval.themes.fmt_srf_outs': ('themes.html#fmt_srf_outs', 'iomeval/themes.py'),
                                'iomeval.themes.get_srf_out': ('themes.html#get_srf_out', 'iomeval/themes.py'),
                                'iomeval.themes.get_srf_outs': ('themes.html#get_srf_outs', 'iomeval/themes.py'),
                                'iomeval.themes.load_all_themes': ('themes.html#load_all_themes', 'iomeval/themes.py'),
                                'iomeval.themes.load_ccp': ('themes.html#load_ccp', 'iomeval/themes.py'),
                                'iomeval.themes.load_enablers': ('themes.html#load_enablers', 'iomeval/themes.py'),
                                'iomeval.themes.load_gcm_lut': ('themes.html#load_gcm_lut', 'iomeval/themes.py'),
                                'iomeval.themes.load_gcms': ('themes.html#load_gcms', 'iomeval/themes.py'),
                                'iomeval.themes.load_srf_outs': ('themes.html#load_srf_outs', 'iomeval/themes.py')}}}
